from launchpadlib.launchpad import Launchpad, EDGE_SERVICE_ROOT
from launchpadlib.credentials import Credentials
from launchpadlib.errors import HTTPError

from django.conf import settings

import os

def lp_login(lp_instance=EDGE_SERVICE_ROOT):
    """
    Return a logged in Launchpad object. 
    
    XXX: Once https://bugs.launchpad.net/soyuz/+bug/510180 is fixed we can 
    probably use "anonymous login" everywhere.
    """
    cachedir = os.path.join(settings.PROJECT_PATH, 'lp_data/cache')
    creddir = os.path.join(settings.PROJECT_PATH, 'lp_data/lp_credentials')
    project = settings.PROJECT_NAME.strip()
    if not os.path.isdir(creddir):
        os.makedirs(creddir)
    cred = os.path.join(creddir, '%s.credentials' % project)

    if os.path.exists(cred):
        credentials = Credentials()
        credentials.load(open(cred))
        launchpad = Launchpad(credentials, lp_instance, cachedir)
    else:
        try:
            launchpad = Launchpad.get_token_and_login(project, lp_instance, 
                                                      cachedir)
        except HTTPError as e:
            raise 'Error connecting to Launchpad: %s' % str(e.value)
        f = open(cred, 'w')
        os.chmod(cred, 0600)
        launchpad.credentials.save(f)
        f.close()
    return launchpad

def get_packagesets(lp):
    """
    Get list of packagesets for current development release of Ubuntu.
    """
    current_series = lp.distributions['ubuntu'].current_series
    packagesets = filter(lambda a: a.distroseries == current_series, lp.packagesets)
    return packagesets
