#Template filter to provide a string similar to the built in timesince
#filter, but slightly fuzzier.
#From <http://djangosnippets.org/snippets/412/> with localization added

from django.utils.translation import ungettext
from django import template

register = template.Library()

@register.filter
def humanize_timediff(timestamp = None):
    """
    Returns a humanized string representing time difference
    between now() and the input timestamp.
    
    The output rounds up to days, hours, minutes, or seconds.
    4 days 5 hours returns '4 days'
    0 days 4 hours 3 minutes returns '4 hours', etc...
    """
    import datetime
    
    timeDiff = datetime.datetime.now() - timestamp
    days = timeDiff.days
    hours = timeDiff.seconds/3600
    minutes = timeDiff.seconds%3600/60
    seconds = timeDiff.seconds%3600%60
    
    tStr = ""
    if days > 0:
        tStr = ungettext('%(days)d day', '%(days)d days', days) % {
            'days' : days
        }
        return tStr
    elif hours > 0:
        tStr = ungettext('%(hours)d hour', '%(hours)d hours', hours) % {
            'hours' : hours
        }
        return tStr
    elif minutes > 0:
        tStr = ungettext('%(minutes)d minute', '%(minutes)d minutes', minutes) % {
            'minutes' : minutes
        }
        return tStr
    elif seconds > 0:
        tStr = ungettext('%(seconds)d second', '%(seconds)d seconds', seconds) % {
            'seconds' : seconds
        }
        return tStr
    else:
        return None
