/**
 * jquery.scrollstay.js
 * scrollFollow for minimalists.
 *
 * Derived from jquery.scrollFollow.js by R.A. Ray,
 * Copyright (c) 2008 Net Perspective (http://kitchen.net-perspective.com/)
 * Licensed under the MIT License (http://www.opensource.org/licenses/mit-license.php)
 * 
 * Removed all animation, delay, cookies and killSwitch.
 * 
 * @author Dylan McCall
 *
 * @projectDescription	jQuery plugin that quietly keeps an element visible as the user scrolls
 * 
 * @version 0.4.0
 * 
 * @requires jquery.js (tested with 1.2.6)
 * 
 * @param offset			int - Number of pixels box should remain from top of viewport
 * 								default: 0
 * @param container	string - ID of the containing div
 * 								default: box's immediate parent
 * @param relativeTo	string - Scroll animation can be relative to either the 'top' or 'bottom' of the viewport
 * 								default: 'top'
 */

( function( $ ) {
	
	$.scrollStay = function ( box, options ) {
		// Convert box into a jQuery object
		box = $( box );
		
		// 'box' is the object to be animated
		var position = box.css( 'position' );
		
		function update() {
			// A bunch of values we need to determine where to animate to
			var viewportHeight = parseInt( $( window ).height() );
			var pageScroll =  parseInt( $( document ).scrollTop() );
			var parentTop =  parseInt( box.cont.offset().top );
			var parentHeight = parseInt( box.cont.attr( 'offsetHeight' ) );
			var boxHeight = parseInt( box.attr( 'offsetHeight' ) + ( parseInt( box.css( 'marginTop' ) ) || 0 ) + ( parseInt( box.css( 'marginBottom' ) ) || 0 ) );
			var aniTop;
			
			/* Make sure the user wants the animation to happen, and it
			   will be helpful. (It isn't helpful if the user is trying
			   to scroll within the box!) */
			if ( viewportHeight > boxHeight ) {
				// If the box should animate relative to the top of the window
				if ( options.relativeTo == 'top' ) {
					// Don't animate until the top of the window is close enough to the top of the box
					if ( box.initialOffsetTop >= ( pageScroll + options.offset ) ) {
						aniTop = box.initialTop;
					} else {
						aniTop = Math.min( ( Math.max( ( -parentTop ), ( pageScroll - box.initialOffsetTop + box.initialTop ) ) + options.offset ), ( parentHeight - boxHeight - box.paddingAdjustment ) );
					}
				}
				// If the box should animate relative to the bottom of the window
				else if ( options.relativeTo == 'bottom' ) {
					// Don't animate until the bottom of the window is close enough to the bottom of the box
					if ( ( box.initialOffsetTop + boxHeight ) >= ( pageScroll + options.offset + viewportHeight ) ) {
						aniTop = box.initialTop;
					} else {
						aniTop = Math.min( ( pageScroll + viewportHeight - boxHeight - options.offset ), ( parentHeight - boxHeight ) );
					}
				}
				
				box.css({ top: aniTop });
			}
		};
		
		// If no parent ID was specified, and the immediate parent does not have an ID
		// options.container will be undefined. So we need to figure out the parent element.
		if ( options.container == '') {
			box.cont = box.parent();
		} else {
			box.cont = $( '#' + options.container );
		}
		
		// Finds the default positioning of the box.
		box.initialOffsetTop =  parseInt( box.offset().top );
		box.initialTop = parseInt( box.css( 'top' ) ) || 0;
		
		// Hack to fix different treatment of boxes positioned 'absolute' and 'relative'
		if ( box.css( 'position' ) == 'relative' ) {
			box.paddingAdjustment = parseInt( box.cont.css( 'paddingTop' ) ) + parseInt( box.cont.css( 'paddingBottom' ) );
		} else {
			box.paddingAdjustment = 0;
		}
		
		// Animate the box when the page is scrolled
		$( window ).bind('scroll resize', function () {
			update();
		} );

		// Run an initial animation on page load
		update();
	};
	
	$.fn.scrollStay = function ( options ) {
		options = options || {};
		options.relativeTo = options.relativeTo || 'top';
		options.offset = options.offset || 0;
		options.container = options.container || this.parent().attr( 'id' );
		
		this.each( function() {
			new $.scrollStay( this, options );
		} );
		
		return this;
	};
})( jQuery );



