#!/usr/bin/python

from django.core.management.base import BaseCommand, CommandError
from django.conf import settings

import subprocess
import sys
import os

def write_version_strings(version, version_name = ''):
    try:
        from bzrlib.branch import Branch
        branch = Branch.open_containing('.')[0]
        bzr_revno = '%s' % (int(branch.revno())+1)
    except:
        bzr_revno = 'unknown'

    file_name = os.path.join(settings.PROJECT_PATH, "version")
    if os.path.exists(file_name):
        os.remove(file_name)
    f = open(file_name, "w")
    f.write("""version: %s
versionname: %s
revno: %s
""" % (version, version_name, bzr_revno))
    f.close()
    return (version, version_name, bzr_revno)

class Command(BaseCommand):
    help = "Prepare release of Harvest."
    args = "<version> [version_name]"

    def handle(self, *args, **options):
        if len(args) < 1:
            raise CommandError("Use this command with release %s" % self.args)
        if len(args) > 2:
            raise CommandError("Too many arguments. Remember to escape your spaces!")
        (version, version_name, bzr_revno) = write_version_strings(*args)
        subprocess.call(["bzr", "tag", version])
        print >> sys.stdout, "Released %s" % version
