#!/usr/bin/python

from django.core.management.base import NoArgsCommand
from django.db import transaction
from django.conf import settings

from common import opportunity_lists
from opportunities import models

import sys

class Command(NoArgsCommand):
    help = "Pull opportunity lists and update them in the DB."

    def update_lists(self):
        for op_list in models.OpportunityList.objects.all():
            (entries, new_date) = opportunity_lists.read_entries(op_list.url, op_list.last_updated)
            if entries:
                op_list.last_updated = new_date
                for (sourcepackage, url, description) in filter(lambda a: len(a)==3, entries):
                    sp, created = models.SourcePackage.objects.get_or_create(name=sourcepackage)
                    try:
                        opportunity = models.Opportunity.objects.get(description=description,
                                                          url=url, sourcepackage=sp,
                                                          opportunitylist=op_list)
                    except models.Opportunity.DoesNotExist:
                        opportunity = models.Opportunity(description=description,
                                                         url=url, sourcepackage=sp,
                                                         since=op_list.last_updated,
                                                         opportunitylist=op_list,
                                                         experience=op_list.experience)
                    opportunity.last_updated = op_list.last_updated
                    opportunity.valid = True
                    opportunity.save()
            else:
                op_list.active = False
            
            if op_list.experience:
                opportunities = models.Opportunity.objects.filter(opportunitylist=op_list, 
                                                                  experience=0)
                for opportunity in opportunities:
                    opportunity.experience = op_list.experience
                    opportunity.save()
            op_list.save()


    def handle_noargs(self, **options):
        transaction.enter_transaction_management()
        try:
            if not settings.PROJECT_PATH:
                print >> sys.stderr, "PROJECT_PATH not set."
                sys.exit(1)
            transaction.managed(True)
            try:
                self.update_lists()
            except:
                transaction.rollback()
                raise
            else:
                transaction.commit()
            finally:
                transaction.managed(False)
        finally:
            transaction.leave_transaction_management()

